==> ssp-center-api-1.1.22-yqf-20221128.101114-1-sources.jar: cn/com/duiba/tuia/ssp/center/api/dto/ProgrammaticMediaReportRspDTO.java <==
package cn.com.duiba.tuia.ssp.center.api.dto;

import lombok.Data;

import java.io.Serializable;
import java.util.List;

/**
 * @Author yuquanfeng
 * @Date 2022/4/11
 * @Description
 * @Param
 * @return
 **/
@Data
public class ProgrammaticMediaReportRspDTO implements Serializable {
    private static final long serialVersionUID = 1L;

    private Long id;
    /**
     * 广告位id
     */
    private Long slotId;
    /**
     * 平台id
     */
    private Integer mediaPlatform;
    /**
     * 账户id
     */
    private String accountId;
    /**
     * 策略id
     */
    private Integer strategyId;
    /**
     * 备注
     */
    private String remark;
    /**
     * 配置列表
     */
    private List<ProgrammaticMediaReportConfigDTO> reportConfigList;
    /**
     * 扩展字段 百度-token
     */
    private String extendValue;
    /**
     * srcId vivo特有
     */
    private String srcId;

    /**
     * 360 key
     */
    private String api360Key;
    /**
     * 360 secret
     */
    private String api360Secret;
    /**
     * 万能wifi钥匙 客户ID
     */
    private String wnClientId;

    /**
     * 万能wifi钥匙 签名密钥
     */
    private String wnSecretkey;

    /**
     * vivo clientId
     */
    private String clientId;
    /**
     * vivo clientSecret
     */
    private String clientSecret;
    /**
     * 固定收益
     */
    private Long income;
    /**
     * oppo api_id
     */
    private String apiId;
    /**
     * oppo api_key
     */
    private String apiKey;

    /**
     * sina 转化ID
     */
    private String convId;
    /**
     * sina token
     */
    private String token;

}

==> ssp-center-api-1.1.52-yqf-20230315.062602-13-sources.jar: cn/com/duiba/tuia/ssp/center/api/dto/ProgrammaticMediaReportRspDTO.java <==
package cn.com.duiba.tuia.ssp.center.api.dto;

import lombok.Data;

import java.io.Serializable;
import java.util.List;

/**
 * @Author yuquanfeng
 * @Date 2022/4/11
 * @Description
 * @Param
 * @return
 **/
@Data
public class ProgrammaticMediaReportRspDTO implements Serializable {
    private static final long serialVersionUID = 1L;

    private Long id;
    /**
     * 广告位id
     */
    private Long slotId;
    /**
     * 平台id
     */
    private Integer mediaPlatform;
    /**
     * 账户id
     */
    private String accountId;
    /**
     * 策略id
     */
    private Integer strategyId;
    /**
     * 备注
     */
    private String remark;
    /**
     * 配置列表
     */
    private List<ProgrammaticMediaReportConfigDTO> reportConfigList;
    /**
     * 扩展字段 百度-token
     */
    private String extendValue;
    /**
     * srcId vivo特有
     */
    private String srcId;

    /**
     * 360 key
     */
    private String api360Key;
    /**
     * 360 secret
     */
    private String api360Secret;
    /**
     * 万能wifi钥匙 客户ID
     */
    private String wnClientId;

    /**
     * 万能wifi钥匙 签名密钥
     */
    private String wnSecretkey;

    /**
     * vivo clientId
     */
    private String clientId;
    /**
     * vivo clientSecret
     */
    private String clientSecret;
    /**
     * 固定收益
     */
    private Long income;
    /**
     * oppo api_id
     */
    private String apiId;
    /**
     * oppo api_key
     */
    private String apiKey;

    /**
     * sina 转化ID
     */
    private String convId;
    /**
     * sina token
     */
    private String token;

    /**
     * youku appKey
     */
    private String appKey;

    /**
     * 凤凰网转化id
     */
    private String fenghuangConvertId;
    /**
     * 凤凰网加密密钥
     */
    private String fenghuangSecretKey;

}
